==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/a7/a7aa8ece8f3756d6449ac10e6e4d3946.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php */
class __TwigTemplate_da95c8610f067fcd35e08fb68f6c0bf2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Doctrine\\Loader;

use Doctrine\\Bundle\\FixturesBundle\\Loader\\SymfonyFixturesLoader;

/**
 * The sole purpose of this class is to make SymfonyFixturesLoader mockable.
 */
final class MauticFixturesLoader implements FixturesLoaderInterface
{
    public function __construct(
        private SymfonyFixturesLoader \$fixturesLoader
    ) {
    }

    public function getFixtures(array \$groups = []): array
    {
        return \$this->fixturesLoader->getFixtures(\$groups);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/a7/a7aa8ece8f3756d6449ac10e6e4d3946.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php */
class __TwigTemplate_da95c8610f067fcd35e08fb68f6c0bf2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Doctrine\\Loader;

use Doctrine\\Bundle\\FixturesBundle\\Loader\\SymfonyFixturesLoader;

/**
 * The sole purpose of this class is to make SymfonyFixturesLoader mockable.
 */
final class MauticFixturesLoader implements FixturesLoaderInterface
{
    public function __construct(
        private SymfonyFixturesLoader \$fixturesLoader
    ) {
    }

    public function getFixtures(array \$groups = []): array
    {
        return \$this->fixturesLoader->getFixtures(\$groups);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Doctrine/Loader/MauticFixturesLoader.php");
    }
}
